@@ -101,7 +101,7 @@ class DebPackageInfo(PackageInfo):
 
 class DebTagLoader(Loader):
 
-    __stateversion__ = Loader.__stateversion__+1
+    __stateversion__ = Loader.__stateversion__+2
 
     def __init__(self, baseurl=None):
         Loader.__init__(self)
@@ -130,6 +130,7 @@ class DebTagLoader(Loader):
         OrPreReq = DebOrPreRequires
         Upg = DebUpgrades
         Cnf = DebConflicts
+        Brk = DebBreaks
         prog = iface.getProgress(self._cache)
         inst = self.getInstalled()
         sysarch = DEBARCH
@@ -185,6 +186,12 @@ class DebTagLoader(Loader):
                     n, r, v = relation
                     cnfargs.append((Cnf, n, r, v))
 
+            value = section.get("breaks")
+            if value:
+                for relation in parserelations(value):
+                    n, r, v = relation
+                    cnfargs.append((Brk, n, r, v))
+
             pkg = self.buildPackage((Pkg, name, version),
                                     prvargs, reqargs, upgargs, cnfargs)
             pkg.loaders[self] = offset
@@ -345,9 +352,7 @@ class DebDirLoader(DebTagLoader):
         pkg = info.getPackage()
         filename = self._filenames[pkg.loaders[self]]
         filepath = os.path.join(self._dir, filename)
-        while filepath.startswith("/"):
-            filepath = filepath[1:]
-        return filepath
+        return filepath.lstrip("/")
 
     def getSize(self, info):
         pkg = info.getPackage()
