@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2005 Canonical
+# Copyright (c) 2005-2007 Canonical
 # Copyright (c) 2004 Conectiva, Inc.
 #
 # Written by Gustavo Niemeyer <niemeyer@conectiva.com>
@@ -51,6 +51,26 @@ CRPMTAG_UPDATE_URL        = 1000023
 
 ENCODINGS = ["utf8", "iso-8859-1"]
 
+
+def get_header_filenames(header):
+    filenames = header[rpm.RPMTAG_OLDFILENAMES]
+    if not filenames and header[rpm.RPMTAG_BASENAMES]:
+        dirindexes = header[rpm.RPMTAG_DIRINDEXES]
+        if type(dirindexes) != list:
+            dirindexes = [dirindexes]
+        dirnames = header[rpm.RPMTAG_DIRNAMES]
+        if type(dirnames) != list:
+            dirnames = [dirnames]
+        basenames = header[rpm.RPMTAG_BASENAMES]
+        if type(basenames) != list:
+            basenames = [basenames]
+        filenames = [dirnames[dirindexes[i]] + basename
+                     for i, basename in enumerate(basenames)]
+    elif type(filenames) != list:
+        filenames = [filenames]
+    return filenames
+
+
 class RPMHeaderPackageInfo(PackageInfo):
 
     class LazyHeader(object):
@@ -86,32 +106,25 @@ class RPMHeaderPackageInfo(PackageInfo):
     def getInstalledSize(self):
         return self._h[rpm.RPMTAG_SIZE]
 
-    def getDescription(self):
-        s = self._h[rpm.RPMTAG_DESCRIPTION]
-        for encoding in ENCODINGS:
-            try:
-                s = s.decode(encoding)
-            except UnicodeDecodeError:
-                continue
-            break
-        else:
-            s = ""
-        return s
-
-    def getSummary(self):
-        s = self._h[rpm.RPMTAG_SUMMARY]
-        if not s:
-            s = ""
-        else:
+    def _getHeaderString(self, tag):
+        result = self._h and self._h[tag] or u""
+        if result:
+            if type(result) == list:
+                # Must have an element, or the check above would fail.
+                result = result[0]
             for encoding in ENCODINGS:
                 try:
-                    s = s.decode(encoding)
+                    result = result.decode(encoding)
                 except UnicodeDecodeError:
                     continue
                 break
-            else:
-                s = ""
-        return s
+        return result
+
+    def getDescription(self):
+        return self._getHeaderString(rpm.RPMTAG_DESCRIPTION)
+
+    def getSummary(self):
+        return self._getHeaderString(rpm.RPMTAG_SUMMARY)
 
     def getGroup(self):
         s = self._loader.getGroup(self._package)
@@ -127,9 +140,7 @@ class RPMHeaderPackageInfo(PackageInfo):
 
     def getPathList(self):
         if self._path is None:
-            paths = self._h[rpm.RPMTAG_OLDFILENAMES]
-            if type(paths) != list:
-                paths = [paths]
+            paths = get_header_filenames(self._h)
             modes = self._h[rpm.RPMTAG_FILEMODES]
             if modes:
                 if type(modes) != list:
@@ -330,10 +341,8 @@ class RPMHeaderLoader(Loader):
                 searcher.addResult(pkg, ratio)
                 continue
             if searcher.path:
-                paths = h[rpm.RPMTAG_OLDFILENAMES]
+                paths = get_header_filenames(h)
                 if paths:
-                    if type(paths) != list:
-                        paths = [paths]
                     for spath, cutoff in searcher.path:
                         for path in paths:
                             _, newratio = globdistance(spath, path, cutoff, ic)
@@ -481,10 +490,7 @@ class RPMHeaderListLoader(RPMHeaderLoader):
         h, offset = rpm.readHeaderFromFD(file.fileno())
         bfp = self.buildFileProvides
         while h:
-            fnlst = h[1027] # RPMTAG_OLDFILENAMES
-            if type(fnlst) != list:
-                fnlst = [fnlst]
-            for fn in fnlst:
+            for fn in get_header_filenames(h):
                 fn = fndict.get(fn)
                 if fn and offset in self._offsets:
                     bfp(self._offsets[offset], (RPMProvides, fn, None))
@@ -494,10 +500,7 @@ class RPMHeaderListLoader(RPMHeaderLoader):
     def loadFileProvidesHDL(self, fndict):
         bfp = self.buildFileProvides
         for offset, h in enumerate(self._hdl):
-            fnlst = h[1027] # RPMTAG_OLDFILENAMES
-            if type(fnlst) != list:
-                fnlst = [fnlst]
-            for fn in fnlst:
+            for fn in get_header_filenames(h):
                 fn = fndict.get(fn)
                 if fn and offset in self._offsets:
                     bfp(self._offsets[offset], (RPMProvides, fn, None))
@@ -658,9 +661,7 @@ class RPMDirLoader(RPMHeaderLoader):
         pkg = info.getPackage()
         filename = self._filenames[pkg.loaders[self]]
         filepath = os.path.join(self._dir, filename)
-        while filepath.startswith("/"):
-            filepath = filepath[1:]
-        return filepath
+        return filepath.lstrip("/")
 
     def getSize(self, info):
         pkg = info.getPackage()
@@ -686,10 +687,7 @@ class RPMDirLoader(RPMHeaderLoader):
                 iface.error("%s: %s" % (os.path.basename(filepath), e))
             else:
                 file.close()
-                fnlst = h[1027] # RPMTAG_OLDFILENAMES
-                if type(fnlst) != list:
-                    fnlst = [fnlst]
-                for fn in fnlst:
+                for fn in get_header_filenames(h):
                     fn = fndict.get(fn)
                     if fn:
                         bfp(self._offsets[i], (RPMProvides, fn, None))
