@@ -1,4 +1,5 @@
 #
+# Copyright (c) 2005 Canonical
 # Copyright (c) 2004 Conectiva, Inc.
 #
 # Written by Gustavo Niemeyer <niemeyer@conectiva.com>
@@ -108,6 +109,8 @@ def parse_options(argv):
                              "pairs modifying a channel"))
     parser.add_option("--remove", action="callback", callback=append_all,
                       help=_("arguments are channel aliases to be removed"))
+    parser.add_option("--remove-all", action="store_true",
+                      help=_("remove all existent channels"))
     parser.add_option("--show", action="callback", callback=append_all,
                       help=_("show channels with given aliases, or all "
                            "channels if no arguments were given"))
@@ -139,6 +142,10 @@ def main(ctrl, opts):
         print _("(*) These fields are necessary for this type.")
         print
         sys.exit(0)
+
+    if sysconf.getReadOnly() is True and opts.show is None:
+        iface.warning(_("Can't edit channels information."))
+        raise Error, _("Configuration is in readonly mode.")
     
     if opts.add is not None:
         if not opts.add and opts.args == ["-"]:
@@ -178,7 +185,7 @@ def main(ctrl, opts):
                     newchannels.append(channel)
             else:
                 raise Error, _("File not found: %s") % arg
-        else:
+        elif opts.add:
             alias = opts.add.pop(0).strip()
             if not alias:
                 raise Error, _("Channel has no alias")
@@ -186,11 +193,13 @@ def main(ctrl, opts):
             for arg in opts.add:
                 if "=" not in arg:
                     raise Error, _("Argument '%s' has no '='") % arg
-                key, value = arg.split("=")
+                key, value = arg.split("=", 1)
                 channel[key.strip()] = value.strip()
             channel = parseChannelData(channel)
             channel["alias"] = alias
             newchannels = [channel]
+        else:
+            raise Error, _("Channel information needed")
 
         newaliases = []
         for channel in newchannels:
@@ -269,6 +278,11 @@ def main(ctrl, opts):
                 if not sysconf.remove(("channels", alias)):
                     iface.warning(_("Channel '%s' not found.") % alias)
 
+    if opts.remove_all:
+        if (not sysconf.get("channels") or opts.yes or
+            iface.askYesNo(_("Remove ALL channels?"))):
+            sysconf.remove("channels")
+
     if opts.enable:
         for alias in opts.enable:
             if not sysconf.has(("channels", alias)):
