@@ -59,21 +59,12 @@ def parse_options(argv):
     parser.add_option("--dump", action="store_true",
                       help=_("dump package names and versions to stderr but "
                              "don't commit operation"))
-    parser.add_option("--dump-noversion", action="store_true",
-                      help=_("dump package names without versions to stderr but "
-                             "don't commit operation"))
-    parser.add_option("--dump-tofile", metavar=_("FILE"),
-                      help=_("dump packages in transaction to a file"))
     opts, args = parser.parse_args(argv)
     opts.args = args
     return opts
 
 def main(ctrl, opts):
 
-    if opts.dump_tofile and not (opts.dump or opts.dump_noversion):
-        raise Error, _("Option 'dump-tofile' must be used with 'dump'"
-                       "or 'dump-noversion'.")
-
     if opts.explain:
         sysconf.set("explain-changesets", True, soft=True)
 
@@ -134,9 +125,7 @@ def main(ctrl, opts):
         if opts.urls:
             ctrl.dumpTransactionURLs(trans)
         elif opts.dump:
-            ctrl.dumpTransactionPackages(trans, "remove", noversion=False, file=opts.dump_tofile)
-        elif opts.dump_noversion:
-            ctrl.dumpTransactionPackages(trans, "remove", noversion=True, file=opts.dump_tofile)
+            ctrl.dumpTransactionPackages(trans, remove=True)
         elif opts.download:
             ctrl.downloadTransaction(trans, confirm=confirm)
         elif opts.stepped:
